# biofuel - Biofuel processing network

This model describes a cost minimization for a multi-period biofuel processing network.

Source paper (see Section "Bioethanol Case Study"):

> Qi Chen & I.E. Grossmann (2019). Effective Generalized Disjunctive Programming Models for Modular Process Synthesis. *Industrial & Engineering Chemistry Research*, 58(15), 5873–5886. https://doi.org/10.1021/acs.iecr.8b04600

Adapted from:

> C.L. Lara, F. Trespalacios, & I.E. Grossmann (2018). Global optimization algorithm for capacitated multi-facility continuous location-allocation problems. Journal of Global Optimization, 71(4), 871–889. https://doi.org/10.1007/s10898-018-0621-6

## Problem Details

### Solution

Optimal objective value: 4067

### Size
- Variables: 36804
    - Boolean: 516
    - Binary: 0
    - Integer: 4320
    - Continuous: 31968
- Constraints: 12884
    - Nonlinear: 12
- Disjuncts: 516
- Disjunctions: 252
